# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
:arrow_up: Upgrade lamindb | [18](https://github.com/laminlabs/lndb-rest/pull/18) | [fredericenard](https://github.com/fredericenard) | 2023-01-05 | 0.4.0
✨ Create sample submission endpoint | [16](https://github.com/laminlabs/lndb-rest/pull/16) | [bpenteado](https://github.com/bpenteado) | 2022-12-07 |
:arrow_up: Upgrade lamindb | [15](https://github.com/laminlabs/lndb-rest/pull/15) | [fredericenard](https://github.com/fredericenard) | 2022-12-07 |
:white_check_mark: Check versions | [12](https://github.com/laminlabs/lndb-rest/pull/12) | [fredericenard](https://github.com/fredericenard) | 2022-12-05 |
:arrow_up: Upgrade lamindb | [13](https://github.com/laminlabs/lndb-rest/pull/13) | [fredericenard](https://github.com/fredericenard) | 2022-12-04 | 0.3.0
:memo: Add enpoint documentation | [10](https://github.com/laminlabs/lndb-rest/pull/10) | [fredericenard](https://github.com/fredericenard) | 2022-12-02 |
:art: Rename package | [9](https://github.com/laminlabs/lndb-rest/pull/9) | [fredericenard](https://github.com/fredericenard) | 2022-11-30 |
:art: Rename package | [8](https://github.com/laminlabs/lndb-rest/pull/8) | [fredericenard](https://github.com/fredericenard) | 2022-11-30 |
:construction: Retrieve rows and schema using table_meta | [6](https://github.com/laminlabs/lndb-rest/pull/6) | [fredericenard](https://github.com/fredericenard) | 2022-11-30 |
:arrow_up: Update lamindb | [5](https://github.com/laminlabs/lndb-rest/pull/5) | [fredericenard](https://github.com/fredericenard) | 2022-11-28 |
:sparkles: Add introspection endpoints | [4](https://github.com/laminlabs/lndb-rest/pull/4) | [fredericenard](https://github.com/fredericenard) | 2022-11-18 | 0.2.0
:fire: Create template for lndb-rest | [3](https://github.com/laminlabs/lndb-rest/pull/3) | [fredericenard](https://github.com/fredericenard) | 2022-11-15 | 0.1.0
